// src/use-user.ts
import { useMemo, useCallback } from "react";
import { useFocusRing } from "@react-aria/focus";
import { user } from "@nextui-org/theme";
import { clsx } from "@nextui-org/shared-utils";
import { useDOMRef } from "@nextui-org/dom-utils";
import { mergeProps } from "@react-aria/utils";
function useUser(props) {
  const {
    as,
    ref,
    name,
    description,
    className,
    styles,
    isFocusable = false,
    avatarProps = {
      isFocusable: false,
      name: typeof name === "string" ? name : void 0
    },
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const { isFocusVisible, focusProps } = useFocusRing();
  const canBeFocused = useMemo(() => {
    return isFocusable || as === "button";
  }, [isFocusable, as]);
  const slots = useMemo(() => user({ isFocusVisible }), [isFocusVisible]);
  const baseStyles = clsx(styles == null ? void 0 : styles.base, className);
  const buttonStyles = useMemo(() => {
    if (as !== "button")
      return "";
    return [
      "p-0",
      "m-0",
      "bg-none",
      "radius-none",
      "appearance-none",
      "outline-none",
      "border-none",
      "cursor-pointer"
    ];
  }, [as]);
  const getUserProps = useCallback(
    () => ({
      ref: domRef,
      tabIndex: canBeFocused ? 0 : -1,
      className: slots.base({
        class: clsx(baseStyles, buttonStyles)
      }),
      ...mergeProps(otherProps, canBeFocused ? focusProps : {})
    }),
    [canBeFocused, slots, baseStyles, focusProps, otherProps]
  );
  return {
    Component,
    className,
    slots,
    name,
    description,
    styles,
    baseStyles,
    focusProps,
    avatarProps,
    getUserProps
  };
}

export {
  useUser
};
